==> owncloud-8.1.0p2.tgz: owncloud/apps/files_external/l10n/ca.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your Dropbox app key and secret are correct." : "Ha fallat en obtenir els testimonis de la petició. Verifiqueu que la clau i la contrasenya de l'aplicació Dropbox són correctes.",
    "Fetching access tokens failed. Verify that your Dropbox app key and secret are correct." : "Ha fallat en obtenir els testimonis de la petició. Verifiqueu que la clau i la contrasenya de l'aplicació Dropbox són correctes.",
    "Please provide a valid Dropbox app key and secret." : "Proporcioneu una clau d'aplicació i secret vàlids per a Dropbox",
    "Step 1 failed. Exception: %s" : "El pas 1 ha fallat. Excepció: %s",
    "Step 2 failed. Exception: %s" : "El pas 2 ha fallat. Excepció: %s",
    "External storage" : "Emmagatzemament extern",
    "Local" : "Local",
    "Location" : "Ubicació",
    "Amazon S3" : "Amazon S3",
    "Key" : "Clau",
    "Secret" : "Secret",
    "Bucket" : "Cub",
    "Amazon S3 and compliant" : "Amazon S3 i similars",
    "Access Key" : "Clau d'accés",
    "Secret Key" : "Clau secreta",
    "Hostname" : "Nom del servidor",
    "Port" : "Port",
    "Region" : "Comarca",
    "Enable SSL" : "Habilita SSL",
    "Enable Path Style" : "Permet l'estil del camí",
    "App key" : "Clau de l'aplicació",
    "App secret" : "Secret de l'aplicació",
    "Host" : "Equip remot",
    "Username" : "Nom d'usuari",
    "Password" : "Contrasenya",
    "Remote subfolder" : "Subcarpeta remota",
    "Secure ftps://" : "Protocol segur ftps://",
    "Client ID" : "Client ID",
    "Client secret" : "Secret del client",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Region (optional for OpenStack Object Storage)" : "Regió (opcional per OpenStack Object Storage)",
    "API Key (required for Rackspace Cloud Files)" : "Clau API (requerit per fitxers al núvol Rackspace)",
    "Tenantname (required for OpenStack Object Storage)" : "Tenantname (requerit per OpenStack Object Storage)",
    "Password (required for OpenStack Object Storage)" : "Contrasenya (requerit per OpenStack Object Storage)",
    "Service Name (required for OpenStack Object Storage)" : "Nom del servei (requerit per OpenStack Object Storage)",
    "URL of identity endpoint (required for OpenStack Object Storage)" : "URL del punt identificador final (requerit per OpenStack Object Storage)",
    "Timeout of HTTP requests in seconds" : "Temps d'expera màxim de les peticions HTTP en segons",
    "Share" : "Comparteix",
    "SMB / CIFS using OC login" : "SMB / CIFS usant acreditació OC",
    "Username as share" : "Nom d'usuari per compartir",
    "URL" : "URL",
    "Secure https://" : "Protocol segur https://",
    "SFTP with secret key login" : "Inici de sessió SFTP amb clau secreta",
    "Public key" : "Clau pública",
    "Storage with id \"%i\" not found" : "No s'ha trobat emmagatzematge amb id \"%i\"",
    "Invalid mount point" : "Punt de muntatge no vàlid",
    "Invalid storage backend \"%s\"" : "Motor d'emmagatzematge no vàlid \"%s\"",
    "Access granted" : "S'ha concedit l'accés",
    "Error configuring Dropbox storage" : "Error en configurar l'emmagatzemament Dropbox",
    "Grant access" : "Concedeix accés",
    "Error configuring Google Drive storage" : "Error en configurar l'emmagatzemament Google Drive",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Enable encryption" : "Habilitar xifrat",
    "Enable previews" : "Habilitar vistes prèvies",
    "Check for changes" : "Comproveu si hi ha canvis",
    "Never" : "Mai",
    "Once every direct access" : "Un cop cada accés directe",
    "Every time the filesystem is used" : "Cada vegada que s'utilitza el sistema d'arxius",
    "All users. Type to select user or group." : "Tots els usuaris. Escriu per seleccionar un usuari o grup.",
    "(group)" : "(grup)",
    "Saved" : "Desat",
    "Generate keys" : "Generar claus",
    "Error generating key pair" : "Error en generar el parell de claus",
    "<b>Note:</b> " : "<b>Nota:</b> ",
    "and" : "i",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> El suport cURL no està activat o instal·lat a PHP. No es pot muntar %s. Demaneu a l'administrador del sistema que l'instal·li.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> El suport FTP per PHP no està activat o no està instal·lat. No es pot muntar %s. Demaneu a l'administrador del sistema que l'instal·li.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> %s no està instal·lat. No es pot muntar %s. Demaneu a l'administrador del sistema que l'instal·li.",
    "No external storage configured" : "Sense emmagatzematge extern configurat",
    "You can add external storages in the personal settings" : "Pot agregar emmagatzematges externs en la configuració personal",
    "Name" : "Nom",
    "Storage type" : "Tipus d'emmagatzemament",
    "Scope" : "Abast",
    "External Storage" : "Emmagatzemament extern",
    "Folder name" : "Nom de la carpeta",
    "Configuration" : "Configuració",
    "Available for" : "Disponible per",
    "Add storage" : "Afegeix emmagatzemament",
    "Advanced settings" : "Configuració avançada",
    "Delete" : "Esborra",
    "Enable User External Storage" : "Habilita l'emmagatzemament extern d'usuari",
    "Allow users to mount the following external storage" : "Permet als usuaris muntar els dispositius externs següents"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/files_external/l10n/ca.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "El pas 1 ha fallat. Excepció: %s",
    "Step 2 failed. Exception: %s" : "El pas 2 ha fallat. Excepció: %s",
    "External storage" : "Emmagatzemament extern",
    "Storage with id \"%i\" not found" : "No s'ha trobat emmagatzematge amb id \"%i\"",
    "Invalid mount point" : "Punt de muntatge no vàlid",
    "Invalid storage backend \"%s\"" : "Motor d'emmagatzematge no vàlid \"%s\"",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Grant access" : "Concedeix accés",
    "Access granted" : "S'ha concedit l'accés",
    "Generate keys" : "Generar claus",
    "Error generating key pair" : "Error en generar el parell de claus",
    "Enable encryption" : "Habilitar xifrat",
    "Enable previews" : "Habilitar vistes prèvies",
    "Check for changes" : "Comproveu si hi ha canvis",
    "Never" : "Mai",
    "Once every direct access" : "Un cop cada accés directe",
    "Every time the filesystem is used" : "Cada vegada que s'utilitza el sistema d'arxius",
    "All users. Type to select user or group." : "Tots els usuaris. Escriu per seleccionar un usuari o grup.",
    "(group)" : "(grup)",
    "Saved" : "Desat",
    "None" : "Cap",
    "App key" : "Clau de l'aplicació",
    "App secret" : "Secret de l'aplicació",
    "Client ID" : "Client ID",
    "Client secret" : "Secret del client",
    "Username" : "Nom d'usuari",
    "Password" : "Contrasenya",
    "API key" : "codi API",
    "Public key" : "Clau pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Cub",
    "Hostname" : "Nom del servidor",
    "Port" : "Port",
    "Region" : "Comarca",
    "Enable SSL" : "Habilita SSL",
    "Enable Path Style" : "Permet l'estil del camí",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcarpeta remota",
    "Secure https://" : "Protocol segur https://",
    "Host" : "Equip remot",
    "Secure ftps://" : "Protocol segur ftps://",
    "Local" : "Local",
    "Location" : "Ubicació",
    "ownCloud" : "ownCloud",
    "Root" : "Arrel",
    "SFTP with secret key login" : "Inici de sessió SFTP amb clau secreta",
    "Share" : "Comparteix",
    "SMB / CIFS using OC login" : "SMB / CIFS usant acreditació OC",
    "Username as share" : "Nom d'usuari per compartir",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "<b>Note:</b> " : "<b>Nota:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> El suport cURL no està activat o instal·lat a PHP. No es pot muntar %s. Demaneu a l'administrador del sistema que l'instal·li.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> El suport FTP per PHP no està activat o no està instal·lat. No es pot muntar %s. Demaneu a l'administrador del sistema que l'instal·li.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> %s no està instal·lat. No es pot muntar %s. Demaneu a l'administrador del sistema que l'instal·li.",
    "No external storage configured" : "Sense emmagatzematge extern configurat",
    "You can add external storages in the personal settings" : "Pot agregar emmagatzematges externs en la configuració personal",
    "Name" : "Nom",
    "Storage type" : "Tipus d'emmagatzemament",
    "Scope" : "Abast",
    "External Storage" : "Emmagatzemament extern",
    "Folder name" : "Nom de la carpeta",
    "Configuration" : "Configuració",
    "Available for" : "Disponible per",
    "Advanced settings" : "Configuració avançada",
    "Delete" : "Esborra",
    "Add storage" : "Afegeix emmagatzemament",
    "Enable User External Storage" : "Habilita l'emmagatzemament extern d'usuari",
    "Allow users to mount the following external storage" : "Permet als usuaris muntar els dispositius externs següents"
},
"nplurals=2; plural=(n != 1);");
